/*******************************************************************************
* File Name: tone.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_tone_H)
#define CY_CLOCK_tone_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void tone_StartEx(uint32 alignClkDiv);
#define tone_Start() \
    tone_StartEx(tone__PA_DIV_ID)

#else

void tone_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void tone_Stop(void);

void tone_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 tone_GetDividerRegister(void);
uint8  tone_GetFractionalDividerRegister(void);

#define tone_Enable()                         tone_Start()
#define tone_Disable()                        tone_Stop()
#define tone_SetDividerRegister(clkDivider, reset)  \
    tone_SetFractionalDividerRegister((clkDivider), 0u)
#define tone_SetDivider(clkDivider)           tone_SetDividerRegister((clkDivider), 1u)
#define tone_SetDividerValue(clkDivider)      tone_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define tone_DIV_ID     tone__DIV_ID

#define tone_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define tone_CTRL_REG   (*(reg32 *)tone__CTRL_REGISTER)
#define tone_DIV_REG    (*(reg32 *)tone__DIV_REGISTER)

#define tone_CMD_DIV_SHIFT          (0u)
#define tone_CMD_PA_DIV_SHIFT       (8u)
#define tone_CMD_DISABLE_SHIFT      (30u)
#define tone_CMD_ENABLE_SHIFT       (31u)

#define tone_CMD_DISABLE_MASK       ((uint32)((uint32)1u << tone_CMD_DISABLE_SHIFT))
#define tone_CMD_ENABLE_MASK        ((uint32)((uint32)1u << tone_CMD_ENABLE_SHIFT))

#define tone_DIV_FRAC_MASK  (0x000000F8u)
#define tone_DIV_FRAC_SHIFT (3u)
#define tone_DIV_INT_MASK   (0xFFFFFF00u)
#define tone_DIV_INT_SHIFT  (8u)

#else 

#define tone_DIV_REG        (*(reg32 *)tone__REGISTER)
#define tone_ENABLE_REG     tone_DIV_REG
#define tone_DIV_FRAC_MASK  tone__FRAC_MASK
#define tone_DIV_FRAC_SHIFT (16u)
#define tone_DIV_INT_MASK   tone__DIVIDER_MASK
#define tone_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_tone_H) */

/* [] END OF FILE */
